netapp_ontap.models.qos_policy_fixed API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.qos_policy_fixed`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class QosPolicyFixedSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the QosPolicyFixed object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `capacity_shared GET POST`

    Specifies whether the capacities are shared across all objects that use this QoS policy-group. Default is false.

  `max_throughput_iops GET POST PATCH`

    Maximum throughput defined by this policy. It is specified in terms of IOPS. 0 means no maximum throughput is enforced.

  `max_throughput_mbps GET POST PATCH`

    Maximum throughput defined by this policy. It is specified in terms of Mbps. 0 means no maximum throughput is enforced.

  `min_throughput_iops GET POST PATCH`

    Minimum throughput defined by this policy. It is specified in terms of IOPS. 0 means no minimum throughput is enforced. These floors are not guaranteed on non-AFF platforms or when FabricPool tiering policies are set.

  `min_throughput_mbps GET POST PATCH`

    Minimum throughput defined by this policy. It is specified in terms of Mbps. 0 means no minimum throughput is enforced.